# Contract Understanding Atticus Dataset (CUAD)

**NeurIPS 2021**: [CUAD: An Expert-Annotated NLP Dataset for Legal Contract Review](https://arxiv.org/abs/2103.06268)

[**Website**](https://www.atticusprojectai.org/cuad)

[**Zenodo**](https://zenodo.org/records/4595826)

[**Datasheet**](https://drive.google.com/file/d/1g8_X3H23cfuD_elHTfhDa8gfCXKV7v_D/view)

**License**: CC BY 4.0 (according to section VI.D of the datasheet)


## Splits

CUAD does not come in any splits.


## Quirks

- The raw data JSON contains non-breaking spaces (`\xA0`) which we remove.
- The text often has very large whitespace gaps.
